F64 class

Constructors

F64(double value)

Properties

data ByteData
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value double
no setter

Methods

abs() F64
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pow(Float exponent) F64
toString() String
A string representation of this object.
inherited

Operators

operator %(Float other) F64
operator *(Float other) F64
operator +(Float other) F64
operator -(Float other) F64
operator /(Float other) F64
operator <(Float other) bool
operator <=(Float other) bool
operator ==(Object other) bool
The equality operator.
inherited
operator >(Float other) bool
operator >=(Float other) bool
operator unary-() F64